summaryrefslogtreecommitdiff
path: root/numpy/core/src
diff options
context:
space:
mode:
Diffstat (limited to 'numpy/core/src')
-rw-r--r--numpy/core/src/_sortmodule.c.src2
-rw-r--r--numpy/core/src/arraymethods.c2
-rw-r--r--numpy/core/src/arrayobject.c26
-rw-r--r--numpy/core/src/multiarraymodule.c18
-rw-r--r--numpy/core/src/scalarmathmodule.c.src4
-rw-r--r--numpy/core/src/scalartypes.inc.src6
-rw-r--r--numpy/core/src/ufuncobject.c2
-rw-r--r--numpy/core/src/umathmodule.c.src4
8 files changed, 32 insertions, 32 deletions
diff --git a/numpy/core/src/_sortmodule.c.src b/numpy/core/src/_sortmodule.c.src
index 47c7520c1..8f40e47ee 100644
--- a/numpy/core/src/_sortmodule.c.src
+++ b/numpy/core/src/_sortmodule.c.src
@@ -24,7 +24,7 @@
#include "Python.h"
-#include "scipy/arrayobject.h"
+#include "numpy/arrayobject.h"
#define PYA_QS_STACK 100
#define SMALL_QUICKSORT 15
diff --git a/numpy/core/src/arraymethods.c b/numpy/core/src/arraymethods.c
index 2b7a53042..2e5ea4ee4 100644
--- a/numpy/core/src/arraymethods.c
+++ b/numpy/core/src/arraymethods.c
@@ -864,7 +864,7 @@ array_reduce(PyArrayObject *self, PyObject *args)
ret = PyTuple_New(3);
if (ret == NULL) return NULL;
- mod = PyImport_ImportModule("scipy.base._internal");
+ mod = PyImport_ImportModule("numpy.base._internal");
if (mod == NULL) {Py_DECREF(ret); return NULL;}
obj = PyObject_GetAttrString(mod, "_reconstruct");
Py_DECREF(mod);
diff --git a/numpy/core/src/multiarraymodule.c b/numpy/core/src/multiarraymodule.c
index 2cce9ad03..6c993b069 100644
--- a/numpy/core/src/multiarraymodule.c
+++ b/numpy/core/src/multiarraymodule.c
@@ -5,7 +5,7 @@
Original file
Copyright (c) 1995, 1996, 1997 Jim Hugunin, hugunin@mit.edu
- Modified for scipy_core in 2005
+ Modified for numpy_core in 2005
Travis E. Oliphant
Assistant Professor at
@@ -22,12 +22,12 @@
*/
#define _MULTIARRAYMODULE
-#include "scipy/arrayobject.h"
+#include "numpy/arrayobject.h"
#define PyAO PyArrayObject
static PyObject *typeDict=NULL; /* Must be explicitly loaded */
-static PyObject *_scipy_internal=NULL; /* A Python module for callbacks */
+static PyObject *_numpy_internal=NULL; /* A Python module for callbacks */
static PyArray_Descr *
@@ -3544,7 +3544,7 @@ _convert_from_commastring(PyObject *obj, int align)
PyArray_Descr *res;
if (!PyString_Check(obj)) return NULL;
- listobj = PyObject_CallMethod(_scipy_internal, "_commastring",
+ listobj = PyObject_CallMethod(_numpy_internal, "_commastring",
"O", obj);
if (!listobj) return NULL;
res = _convert_from_list(listobj, align, 0);
@@ -3593,7 +3593,7 @@ then it will be checked for conformity and used directly.
static PyArray_Descr *
_use_fields_dict(PyObject *obj, int align)
{
- return (PyArray_Descr *)PyObject_CallMethod(_scipy_internal,
+ return (PyArray_Descr *)PyObject_CallMethod(_numpy_internal,
"_usefields",
"Oi", obj, align);
}
@@ -3734,7 +3734,7 @@ PyArray_DescrConverter2(PyObject *obj, PyArray_Descr **at)
quite a flexible concept.
This is the central code that converts Python objects to
- Type-descriptor objects that are used throughout scipy.
+ Type-descriptor objects that are used throughout numpy.
*/
/* new reference in *at */
@@ -5492,9 +5492,9 @@ DL_EXPORT(void) initmultiarray(void) {
if (set_typeinfo(d) != 0) goto err;
- _scipy_internal = \
- PyImport_ImportModule("scipy.base._internal");
- if (_scipy_internal != NULL) return;
+ _numpy_internal = \
+ PyImport_ImportModule("numpy.base._internal");
+ if (_numpy_internal != NULL) return;
err:
/* Check for errors */
diff --git a/numpy/core/src/scalarmathmodule.c.src b/numpy/core/src/scalarmathmodule.c.src
index dc2c3c198..ec210d42e 100644
--- a/numpy/core/src/scalarmathmodule.c.src
+++ b/numpy/core/src/scalarmathmodule.c.src
@@ -4,8 +4,8 @@
NOT FINISHED
*/
-#include "scipy/arrayobject.h"
-#include "scipy/ufuncobject.h"
+#include "numpy/arrayobject.h"
+#include "numpy/ufuncobject.h"
/**begin repeat
diff --git a/numpy/core/src/scalartypes.inc.src b/numpy/core/src/scalartypes.inc.src
index 629adbcf0..972b2424f 100644
--- a/numpy/core/src/scalartypes.inc.src
+++ b/numpy/core/src/scalartypes.inc.src
@@ -641,14 +641,14 @@ gentype_flags_get(PyObject *self)
{
static int flags=CONTIGUOUS | OWNDATA | FORTRAN | ALIGNED;
- return PyObject_CallMethod(_scipy_internal, "flagsobj", "Oii",
+ return PyObject_CallMethod(_numpy_internal, "flagsobj", "Oii",
self, flags, 1);
}
static PyObject *
voidtype_flags_get(PyVoidScalarObject *self)
{
- return PyObject_CallMethod(_scipy_internal, "flagsobj", "Oii",
+ return PyObject_CallMethod(_numpy_internal, "flagsobj", "Oii",
self, self->flags, 1);
}
@@ -1194,7 +1194,7 @@ gentype_reduce(PyObject *self, PyObject *args)
if (PyObject_AsReadBuffer(self, (const void **)&buffer, &buflen)<0) {
Py_DECREF(ret); return NULL;
}
- mod = PyImport_ImportModule("scipy.base.multiarray");
+ mod = PyImport_ImportModule("numpy.base.multiarray");
if (mod == NULL) return NULL;
obj = PyObject_GetAttrString(mod, "scalar");
Py_DECREF(mod);
diff --git a/numpy/core/src/ufuncobject.c b/numpy/core/src/ufuncobject.c
index 47aad4828..1b5a5f31f 100644
--- a/numpy/core/src/ufuncobject.c
+++ b/numpy/core/src/ufuncobject.c
@@ -3119,7 +3119,7 @@ static char Ufunctype__doc__[] =
static PyTypeObject PyUFunc_Type = {
PyObject_HEAD_INIT(0)
0, /*ob_size*/
- "scipy.ufunc", /*tp_name*/
+ "numpy.ufunc", /*tp_name*/
sizeof(PyUFuncObject), /*tp_basicsize*/
0, /*tp_itemsize*/
/* methods */
diff --git a/numpy/core/src/umathmodule.c.src b/numpy/core/src/umathmodule.c.src
index 5096f3361..dd140354b 100644
--- a/numpy/core/src/umathmodule.c.src
+++ b/numpy/core/src/umathmodule.c.src
@@ -1,9 +1,9 @@
/* -*- c -*- */
#include "Python.h"
-#include "scipy/arrayobject.h"
+#include "numpy/arrayobject.h"
#define _UMATHMODULE
-#include "scipy/ufuncobject.h"
+#include "numpy/ufuncobject.h"
#include "abstract.h"
#include <math.h>
diff --git a/numpy/core/src/arrayobject.c b/numpy/core/src/arrayobject.c
index 72db76373..1d9e15976 100644
--- a/numpy/core/src/arrayobject.c
+++ b/numpy/core/src/arrayobject.c
@@ -3922,7 +3922,7 @@ array_ndim_get(PyArrayObject *self)
static PyObject *
array_flags_get(PyArrayObject *self)
{
- return PyObject_CallMethod(_scipy_internal, "flagsobj", "Oii",
+ return PyObject_CallMethod(_numpy_internal, "flagsobj", "Oii",
self, self->flags, 0);
}
@@ -4648,9 +4648,9 @@ static char Arraytype__doc__[] =
"A array object represents a multidimensional, homogeneous array\n"
" of fixed-size items. An associated data-type-descriptor object\n"
" details the data-type in an array (including byteorder and any\n"
- " fields). An array can be constructed using the scipy.array\n"
+ " fields). An array can be constructed using the numpy.array\n"
" command. Arrays are sequence, mapping and numeric objects.\n"
- " More information is available in the scipy module and by looking\n"
+ " More information is available in the numpy module and by looking\n"
" at the methods and attributes of an array.\n\n"
" ndarray.__new__(subtype, shape=, dtype=int_, buffer=None, \n"
" offset=0, strides=None, fortran=False)\n\n"
@@ -4660,14 +4660,14 @@ static char Arraytype__doc__[] =
" 2) If buffer is an object exporting the buffer interface, then\n"
" all keywords are interpreted.\n"
" The dtype parameter can be any object that can be interpreted \n"
- " as a scipy.dtypedescr object.\n\n"
+ " as a numpy.dtypedescr object.\n\n"
" No __init__ method is needed because the array is fully \n"
" initialized after the __new__ method.";
static PyTypeObject PyBigArray_Type = {
PyObject_HEAD_INIT(NULL)
0, /*ob_size*/
- "scipy.bigndarray", /*tp_name*/
+ "numpy.bigndarray", /*tp_name*/
sizeof(PyArrayObject), /*tp_basicsize*/
0, /*tp_itemsize*/
/* methods */
@@ -4733,7 +4733,7 @@ static PyTypeObject PyBigArray_Type = {
static PyTypeObject PyArray_Type = {
PyObject_HEAD_INIT(NULL)
0, /*ob_size*/
- "scipy.ndarray", /*tp_name*/
+ "numpy.ndarray", /*tp_name*/
sizeof(PyArrayObject), /*tp_basicsize*/
0, /*tp_itemsize*/
};
@@ -6192,7 +6192,7 @@ PyArray_CanCastTo(PyArray_Descr *from, PyArray_Descr *to)
/*********************** Element-wise Array Iterator ***********************/
/* Aided by Peter J. Verveer's nd_image package and scipy's arraymap ****/
/* and Python's array iterator ***/
@@ -6841,7 +6841,7 @@ static PyMemberDef iter_members[] = {
static PyTypeObject PyArrayIter_Type = {
PyObject_HEAD_INIT(NULL)
0, /* ob_size */
- "scipy.flatiter", /* tp_name */
+ "numpy.flatiter", /* tp_name */
sizeof(PyArrayIterObject), /* tp_basicsize */
0, /* tp_itemsize */
/* methods */
@@ -7543,7 +7543,7 @@ arraymapiter_dealloc(PyArrayMapIterObject *mit)
static PyTypeObject PyArrayMapIter_Type = {
PyObject_HEAD_INIT(NULL)
0, /* ob_size */
- "scipy.mapiter", /* tp_name */
+ "numpy.mapiter", /* tp_name */
sizeof(PyArrayIterObject), /* tp_basicsize */
0, /* tp_itemsize */
/* methods */
@@ -7821,7 +7821,7 @@ static PyMethodDef arraymultiter_methods[] = {
static PyTypeObject PyArrayMultiIter_Type = {
PyObject_HEAD_INIT(NULL)
0, /* ob_size */
- "scipy.broadcast", /* tp_name */
+ "numpy.broadcast", /* tp_name */
sizeof(PyArrayMultiIterObject), /* tp_basicsize */
0, /* tp_itemsize */
/* methods */
@@ -7996,7 +7996,7 @@ arraydescr_protocol_descr_get(PyArray_Descr *self)
return res;
}
- return PyObject_CallMethod(_scipy_internal, "_array_descr",
+ return PyObject_CallMethod(_numpy_internal, "_array_descr",
"O", self);
}
@@ -8134,7 +8134,7 @@ arraydescr_reduce(PyArray_Descr *self, PyObject *args)
ret = PyTuple_New(3);
if (ret == NULL) return NULL;
- mod = PyImport_ImportModule("scipy.base.multiarray");
+ mod = PyImport_ImportModule("numpy.base.multiarray");
if (mod == NULL) {Py_DECREF(ret); return NULL;}
obj = PyObject_GetAttrString(mod, "dtypedescr");
Py_DECREF(mod);
@@ -8424,7 +8424,7 @@ arraydescr_compare(PyArray_Descr *self, PyObject *other)
static PyTypeObject PyArrayDescr_Type = {
PyObject_HEAD_INIT(NULL)
0, /* ob_size */
- "scipy.dtypedescr", /* tp_name */
+ "numpy.dtypedescr", /* tp_name */
sizeof(PyArray_Descr), /* tp_basicsize */
0, /* tp_itemsize */
/* methods */
@@ -6192,7 +6192,7 @@ PyArray_CanCastTo(PyArray_Descr *from, PyArray_Descr *to)
/*********************** Element-wise Array Iterator ***********************/
-/* Aided by Peter J. Verveer's nd_image package and scipy's arraymap ****/
+/* Aided by Peter J. Verveer's nd_image package and numpy's arraymap ****/
/* and Python's array iterator ***/